//////////////////////////////////////////////////////////////////////////////////
//                                                                              //
//  This file is part of Web Documentation Typesetter (WDT).                    //
//                                                                              //
//  WDT is free software; you  can redistribute it and/or  modify it under the  //
//  terms of the GNU General  Public License as published by the Free Software  //
//  Foundation; either version 2 of the License, or (at your option) any later  //
//  version.                                                                    //
//                                                                              //
//  WDT is distributed in the  hope that it  will be useful,  but WITHOUT  ANY  //
//  WARRANTY; without  even the implied warranty of MERCHANTABILITY or FITNESS  //
//  FOR A  PARTICULAR  PURPOSE.  See the GNU  General Public  License for more  //
//  details.                                                                    //
//                                                                              //
//  You should have received a copy of the GNU General Public License along     //
//  with WDT; if not, write to the Free Software Foundation, Inc.,              //
//  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA                    //
//                                                                              //
//  For more information, see COPYING file                                      //
//                                                                              //
//  Copyright (C) 2005 Stanislav Yaglo                                          //
//                                                                              //
//  Author: Stanislav Yaglo <stas@plg.lrn.ru>                                   //
//                                                                              //
//////////////////////////////////////////////////////////////////////////////////

#include <iostream>
#include <string>

#include "generator.h"
#include "units.h"

void Generator::generateHTML(Document *doc)
{
	using namespace std;
	cout << "<html>\n";
	cout <<	"  <head>\n";
	cout << "    <title>" << doc->title << "</title>\n";
	cout << "    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=koi8-r\"\n";
	cout << "    <link href=\"style.css\" rel=\"stylesheet\" type=\"text/css\">\n";
	cout << "  </head>\n";
	cout << "<body>\n";
	
	cout << "<h1>" << doc->title << "</h1>\n";
	
	for (int i = 0; i < doc->authors.size(); i++)
	{
		cout << "<center><b>: <i>" << doc->authors[i] << "</i></b></center>\n";
	}
	
	doc->makeTOC();
	
	cout << "<p><b>:</b></p>\n";
	cout << "<ul>\n";
	for (int i = 0; i < doc->tocID.size(); i++)
	{
		cout << "  <li><b><a href=\"#id" << doc->tocID[i] << "\">" << doc->unitSect[i] << "</a></b></li>" << endl;
	}
	cout << "</ul>\n";

	int j = 1;
	for (int i = 0; i < doc->modelID.size(); i++)
	{
		switch(doc->modelT[i])
		{
			case T_SECT:
				cout << "<h2>" << "<a name=\"id" << j++ << "\"></a>" << doc->unitSect[doc->modelID[i]-1] << "</h2>\n";
				break;
				
			case T_P:
				{
					std::string para = parsePara(doc->unitP[doc->modelID[i]-1]);
					cout << "<p>" << para << "</p>\n";
				}
				break;
			
			default:
				cout << "  <br>\n";
				break;
		}
	}
	
	cout << "<hr>\n";
	cout << "<center><span style=\"font-size: 90%;\">  Web Documentation Typesetter  <a href=\"mailto:stas@plg.lrn.ru\"> </a>.</span></center>\n";
	
	cout << "</body>\n</html>\n";
}

std::string Generator::parsePara(std::string text)
{
	std::string out = text;
/*	int start, length=0;
	
	for (int i = 0; i < text.size(); i++)
	{
		if (text[i] == '{')
		{
			if (text[i-1] != '\\') {
				start = i;
				
				do length++; while (text[i++] != '}');
			}
		}
	}
*/	
	return out;
}	
// vim:sw=4 ts=4

