//////////////////////////////////////////////////////////////////////////////////
//                                                                              //
//  This file is part of Web Documentation Typesetter (WDT).                    //
//                                                                              //
//  WDT is free software; you  can redistribute it and/or  modify it under the  //
//  terms of the GNU General  Public License as published by the Free Software  //
//  Foundation; either version 2 of the License, or (at your option) any later  //
//  version.                                                                    //
//                                                                              //
//  WDT is distributed in the  hope that it  will be useful,  but WITHOUT  ANY  //
//  WARRANTY; without  even the implied warranty of MERCHANTABILITY or FITNESS  //
//  FOR A  PARTICULAR  PURPOSE.  See the GNU  General Public  License for more  //
//  details.                                                                    //
//                                                                              //
//  You should have received a copy of the GNU General Public License along     //
//  with WDT; if not, write to the Free Software Foundation, Inc.,              //
//  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA                    //
//                                                                              //
//  For more information, see COPYING file                                      //
//                                                                              //
//  Copyright (C) 2005 Stanislav Yaglo                                          //
//                                                                              //
//  Author: Stanislav Yaglo <stas@plg.lrn.ru>                                   //
//                                                                              //
//////////////////////////////////////////////////////////////////////////////////

#include <iostream>
#include <string>

#include "parser.h"

Parser::Parser(Document *docum)
{
	doc = new Document();
	doc = docum;
}

Parser::~Parser()
{
	//delete doc;
}

void Parser::parseDoc()
{
	scan();
}

void Parser::scan()
{
	std::string line;
	std::string text = "";
	
	for(int i = 0; i < doc->source.size(); i++)
	{
		line = doc->source[i];
		
		if (line[0] == '.')
			tagFound(line);
		else if (line[0] == '\t')
			paraFound(i);
	}
}

void Parser::tagFound(std::string line)
{
	char c;
	int curpos = 1;
	std::string tagName;
	
	do
	{
		c = line[curpos++];
	}
	while (c == '\t' || c == ' ');

	for (int i = curpos-1; i < line.size(); i++) {
		c = line[i];
		if (isalpha(c))
			tagName += c;
		else {
			curpos = i;
			std::cerr << tagName << std::endl;
			break;
		}
	}

	do
		c = line[curpos++];
	while (c == '\t' || c == ' ' || c == ':');

	line.erase(0, curpos-1);

	if (tagName == "title")
		titleTag(line);
	else if (tagName == "author")
		authorTag(line);
	else if (tagName == "sect")
		sectTag(line);
}

void Parser::titleTag(std::string line)
{
	doc->title = line;
}

void Parser::authorTag(std::string line)
{
	doc->authors.push_back(line);
}
	
void Parser::sectTag(std::string line)
{
	doc->unitSect.push_back(line);
	doc->modelT.push_back(T_SECT);
	doc->modelID.push_back(doc->unitSect.size());
}

int Parser::paraFound(int iter)
{
	std::string text = "";
	std::string line;
	
	do {
		line = doc->source[iter];
		text.append(line);
		text.append("\n");
		iter++;
	} while (line != "");
	
	doc->unitP.push_back(text);
	doc->modelT.push_back(T_P);
	doc->modelID.push_back(doc->unitP.size());
	
	return iter--;
}

// vim:sw=4 ts=4

